@@ -26,11 +26,10 @@
 #' @seealso \code{\link[PGRdup]{KWIC}}
 #'   
 #' @export
-print.KWIC <- function(x,...)
-{
+print.KWIC <- function(x,...) {
   cat(paste("KWIC fields : ", sep = ""))
   cat(paste(x$Fields, sep = ""))
   cat(paste("\n", "Number of keywords : ", nrow(x[[1]]), sep = ""))
   cat(paste("\n", "Number of distinct keywords : ",
             length(unique(x[[1]]$KEYWORD)), sep = ""))
-}
\ No newline at end of file
+}
